@@ -99,7 +99,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch>"
-__version__ = "3.0.1"
+__version__ = "3.0.2"
 
 
 
@@ -356,10 +356,10 @@ class Block(object):
                 if type(x) is not int:
                     i_first_nonint = i
                     break
-            if i_first_nonint == 0:
-                raise AccessError("Attempted to set a block entry with a non-integer(s) index")
-            else:
-                self.entries[_autotuple(args[:i_first_nonint])] = _autotuple(args[i_first_nonint:])
+            # if i_first_nonint == 0:
+            #     raise AccessError("Attempted to set a block entry with a non-integer(s) index: %s" % str(args))
+            # else:
+            self.entries[_autotuple(args[:i_first_nonint])] = _autotuple(args[i_first_nonint:])
 
     "Alias"
     set = set_value
@@ -566,8 +566,8 @@ def readSLHA(spcstr, ignorenobr=False, ignorenomass=False, ignoreblocks=[]):
     # print blocks.keys()
     try:
         for pid in blocks["MASS"].keys():
-            if decays.has_key(pid):
-                decays[pid].mass = blocks["MASS"][pid]
+            ## Set zero width for particles that have mass but no decays, assuming them to be stable
+            decays.setdefault(pid, Particle(pid, 0)).mass = blocks["MASS"][pid]
     except:
         if not ignorenomass:
             raise ParseError("No MASS block found: cannot populate particle masses")
@@ -881,6 +881,7 @@ def readISAWIG(isastr, ignorenobr=False):
     ## Populate decays
     for n in xrange(numentries):
         numdecays = int(getnextvalidline())
+        #print n+1, "/", numentries, numdecays
         for d in xrange(numdecays):
             #print n, numentries-1, d, numdecays-1
             decayitems = getnextvalidlineitems()
@@ -1001,7 +1002,10 @@ def writeISAWIG(doc, ignorenobr=False, precision=8):
     out += "%d\n" % massout.count("\n")
     out += massout
 
-    assert(len(masses) == len(decays))
+    # TODO: it's possible for there to be entries in DECAYS which aren't in MASS (sigh)
+    # print len(masses), len(decays)
+    # print zip(sorted(masses.keys()), sorted(decays.keys()))
+    # assert(len(masses) == len(decays))
 
     ## Next each particles decay modes together with their branching ratios and matrix element codes
     ##   Number of decay modes for a given particle (IDK)
@@ -1176,7 +1180,9 @@ def writeISAWIG(doc, ignorenobr=False, precision=8):
                 ids[i] = pid
             ids = map(str, ids)
             decayout += " ".join(ids) + "\n"
-        decayout = "%d\n" % decayout.count("\n") + decayout
+        ndecayout = decayout.count("\n")
+        # if ndecayout:
+        decayout = ("%d\n" % ndecayout) + decayout
         out += decayout
 
     ## Now the SUSY parameters
